@@ -17,6 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
 #include <sys/time.h>
 #include "v4lsrc_calls.h"
@@ -60,7 +64,7 @@ static gboolean              gst_v4lsrc_srcconvert   (GstPad         *pad,
                                                       gint64         src_value,
                                                       GstFormat      *dest_format,
                                                       gint64         *dest_value);
-static GstPadConnectReturn   gst_v4lsrc_srcconnect   (GstPad         *pad,
+static GstPadLinkReturn   gst_v4lsrc_srcconnect   (GstPad         *pad,
                                                       GstCaps        *caps);
 static GstBuffer*            gst_v4lsrc_get          (GstPad         *pad);
 
@@ -162,7 +166,7 @@ gst_v4lsrc_init (GstV4lSrc *v4lsrc)
   gst_element_add_pad(GST_ELEMENT(v4lsrc), v4lsrc->srcpad);
 
   gst_pad_set_get_function (v4lsrc->srcpad, gst_v4lsrc_get);
-  gst_pad_set_connect_function (v4lsrc->srcpad, gst_v4lsrc_srcconnect);
+  gst_pad_set_link_function (v4lsrc->srcpad, gst_v4lsrc_srcconnect);
   gst_pad_set_convert_function (v4lsrc->srcpad, gst_v4lsrc_srcconvert);
 
   v4lsrc->bufferpool = gst_buffer_pool_new(
@@ -239,11 +243,11 @@ gst_v4lsrc_srcconvert (GstPad    *pad,
 }
 
 
-static GstPadConnectReturn
+static GstPadLinkReturn
 gst_v4lsrc_srcconnect (GstPad  *pad,
                        GstCaps *vscapslist)
 {
-  GstPadConnectReturn ret_val;
+  GstPadLinkReturn ret_val;
   GstV4lSrc *v4lsrc;
   GstCaps *caps, *newcaps;
   gint palette;
@@ -255,11 +259,11 @@ gst_v4lsrc_srcconnect (GstPad  *pad,
   if (GST_V4L_IS_ACTIVE(GST_V4LELEMENT(v4lsrc)))
   {
     if (!gst_v4lsrc_capture_deinit(v4lsrc))
-      return GST_PAD_CONNECT_REFUSED;
+      return GST_PAD_LINK_REFUSED;
   }
   else if (!GST_V4L_IS_OPEN(GST_V4LELEMENT(v4lsrc)))
   {
-    return GST_PAD_CONNECT_DELAYED;
+    return GST_PAD_LINK_DELAYED;
   }
 
   palette = v4lsrc->palette;
@@ -419,22 +423,22 @@ gst_v4lsrc_srcconnect (GstPad  *pad,
 
     gst_caps_debug (newcaps, "new caps to set on v4lsrc's src pad");
 
-    if ((ret_val = gst_pad_try_set_caps(v4lsrc->srcpad, newcaps)) == GST_PAD_CONNECT_REFUSED)
+    if ((ret_val = gst_pad_try_set_caps(v4lsrc->srcpad, newcaps)) == GST_PAD_LINK_REFUSED)
       continue;
-    else if (ret_val == GST_PAD_CONNECT_DELAYED)
-      return GST_PAD_CONNECT_DELAYED;
+    else if (ret_val == GST_PAD_LINK_DELAYED)
+      return GST_PAD_LINK_DELAYED;
 
     if (!gst_v4lsrc_set_capture(v4lsrc, v4lsrc->width, v4lsrc->height, palette))
-      return GST_PAD_CONNECT_REFUSED;
+      return GST_PAD_LINK_REFUSED;
 
     if (!gst_v4lsrc_capture_init(v4lsrc))
-      return GST_PAD_CONNECT_REFUSED;
+      return GST_PAD_LINK_REFUSED;
 
-    return GST_PAD_CONNECT_DONE;
+    return GST_PAD_LINK_DONE;
   }
 
   /* still nothing - no good caps */
-  return GST_PAD_CONNECT_REFUSED;
+  return GST_PAD_LINK_REFUSED;
 }
 
 
