@@ -24,7 +24,6 @@ struct _GstXvImage
 {
   GstImage parent;
 
-  GstXWindow *window;
   GstXvImageType  type;
 #ifdef HAVE_XVIDEO
   XvImage *ximage;
@@ -38,8 +37,8 @@ struct _GstXvImage
   gint width, height;
 };
 
-void 		_gst_xvimage_init		(void);
-gboolean 	_gst_xvimage_check_xvideo	(void);
+void 		_gst_xvimage_init		(Display *display);
+gboolean 	_gst_xvimage_check_xvideo	(Display *display);
 
 GstCaps* 	_gst_xvimage_get_capslist	(void);
 
